@@ -63,6 +63,7 @@
 #define mp_cmp TclBN_mp_cmp
 #define mp_cmp_d TclBN_mp_cmp_d
 #define mp_cmp_mag TclBN_mp_cmp_mag
+#define mp_cnt_lsb TclBN_mp_cnt_lsb
 #define mp_copy TclBN_mp_copy
 #define mp_count_bits TclBN_mp_count_bits
 #define mp_div TclBN_mp_div
@@ -454,12 +455,17 @@ EXTERN int		TclBN_s_mp_sub(mp_int *a, mp_int *b, mp_int *c);
 #ifndef TclBN_mp_init_set_int_TCL_DECLARED
 #define TclBN_mp_init_set_int_TCL_DECLARED
 /* 61 */
-EXTERN int		TclBN_mp_init_set_int(mp_int*a, unsigned long i);
+EXTERN int		TclBN_mp_init_set_int(mp_int *a, unsigned long i);
 #endif
 #ifndef TclBN_mp_set_int_TCL_DECLARED
 #define TclBN_mp_set_int_TCL_DECLARED
 /* 62 */
-EXTERN int		TclBN_mp_set_int(mp_int*a, unsigned long i);
+EXTERN int		TclBN_mp_set_int(mp_int *a, unsigned long i);
+#endif
+#ifndef TclBN_mp_cnt_lsb_TCL_DECLARED
+#define TclBN_mp_cnt_lsb_TCL_DECLARED
+/* 63 */
+EXTERN int		TclBN_mp_cnt_lsb(mp_int *a);
 #endif
 
 typedef struct TclTomMathStubs {
@@ -527,8 +533,9 @@ typedef struct TclTomMathStubs {
     int (*tclBN_s_mp_mul_digs) (mp_int *a, mp_int *b, mp_int *c, int digs); /* 58 */
     int (*tclBN_s_mp_sqr) (mp_int *a, mp_int *b); /* 59 */
     int (*tclBN_s_mp_sub) (mp_int *a, mp_int *b, mp_int *c); /* 60 */
-    int (*tclBN_mp_init_set_int) (mp_int*a, unsigned long i); /* 61 */
-    int (*tclBN_mp_set_int) (mp_int*a, unsigned long i); /* 62 */
+    int (*tclBN_mp_init_set_int) (mp_int *a, unsigned long i); /* 61 */
+    int (*tclBN_mp_set_int) (mp_int *a, unsigned long i); /* 62 */
+    int (*tclBN_mp_cnt_lsb) (mp_int *a); /* 63 */
 } TclTomMathStubs;
 
 #ifdef __cplusplus
@@ -797,6 +804,10 @@ extern TclTomMathStubs *tclTomMathStubsPtr;
 #define TclBN_mp_set_int \
 	(tclTomMathStubsPtr->tclBN_mp_set_int) /* 62 */
 #endif
+#ifndef TclBN_mp_cnt_lsb
+#define TclBN_mp_cnt_lsb \
+	(tclTomMathStubsPtr->tclBN_mp_cnt_lsb) /* 63 */
+#endif
 
 #endif /* defined(USE_TCL_STUBS) && !defined(USE_TCL_STUB_PROCS) */
 
