@@ -8,8 +8,6 @@
  *
  * See the file "license.terms" for information on usage and redistribution of
  * this file, and for a DISCLAIMER OF ALL WARRANTIES.
- *
- * RCS: @(#) $Id: tclMacOSXFCmd.c,v 1.12 2007/04/23 20:46:14 das Exp $
  */
 
 #include "tclInt.h"
@@ -589,7 +587,7 @@ NewOSTypeObj(
     Tcl_Obj *objPtr;
 
     TclNewObj(objPtr);
-    Tcl_InvalidateStringRep(objPtr);
+    TclInvalidateStringRep(objPtr);
     objPtr->internalRep.longValue = (long) osType;
     objPtr->typePtr = &tclOSTypeType;
     return objPtr;
@@ -625,8 +623,10 @@ SetOSTypeFromAny(
     Tcl_UtfToExternalDString(encoding, string, length, &ds);
 
     if (Tcl_DStringLength(&ds) > 4) {
-	Tcl_AppendResult(interp, "expected Macintosh OS type but got \"",
-		string, "\": ", NULL);
+	if (interp) {
+	    Tcl_AppendResult(interp, "expected Macintosh OS type but got \"",
+		    string, "\": ", NULL);
+	}
 	result = TCL_ERROR;
     } else {
 	OSType osType;
